<?php
/**
 * Plugin Name: WooCommerce Shop Assistant JARVIS
 * Plugin URI: https://www.quantumcloud.com/
 * Description: Let your store help your customers like a real person with your own completely customizable search.
 * Version: 2.5.0
 * @package   JARVIS
 * @author    QuantumCloud
 * @category  WooCommerce
 * Author: QunatumCloud
 * Author URI: https://www.quantumcloud.com/
 * Requires at least: 4.0
 * Tested up to: 4.9
 * Text Domain: jarvis
 * Domain Path: /lang/
 * License: GPL2
 */


if (!defined('ABSPATH')) exit; // Exit if accessed directly

define('QC_JARVIS_VERSION', '2.0.1');
define('QC_JARVIS_REQUIRED_WOOCOMMERCE_VERSION', 2.2);
define('QC_JARVIS_PLUGIN_DIR_PATH', basename(plugin_dir_path(__FILE__)));
define('QC_JARVIS_PLUGIN_URL', plugin_dir_url(__FILE__));
define('QC_JARVIS_IMG_URL', QC_JARVIS_PLUGIN_URL . "images/");
define('QC_JARVIS_IMG_ABSOLUTE_PATH', plugin_dir_path(__FILE__) . "images");
require_once("functions.php");
require_once("class-plugin-deactivate-feedback.php");


/**
 * Main Class.
 */
class WC_Jarvis
{

    private $id = 'jarvis';

    private static $instance;

    /**
     *  Get Instance creates a singleton class that's cached to stop duplicate instances
     */
    public static function get_instance()
    {
        if (!self::$instance) {
            self::$instance = new self();
            self::$instance->init();
        }
        return self::$instance;
    }

    /**
     *  Construct empty on purpose
     */

    private function __construct()
    {
    }

    /**
     *  Init behaves like, and replaces, construct
     */

    public function init()
    {

        // Check if WooCommerce is active, and is required WooCommerce version.
        if (!class_exists('WooCommerce') || version_compare(get_option('woocommerce_db_version'), QC_JARVIS_REQUIRED_WOOCOMMERCE_VERSION, '<')) {
            add_action('admin_notices', array($this, 'woocommerce_inactive_notice'));
            return;
        }

        $this->general_includes();

        add_action('admin_menu', array($this, 'admin_menu'));

        add_action('widgets_init', array($this, 'register_widgets'));

        if ((!empty($_GET["page"])) && ($_GET["page"] == "jarvis")) {

            add_action('woocommerce_init', array($this, 'backend_includes'));

            add_action('admin_init', array($this, 'jarvis_save_options'));
        }

        add_action('admin_enqueue_scripts', array($this, 'admin_scripts'));

        if (!is_admin()) {

            add_action('wp_enqueue_scripts', array($this, 'frontend_scripts'));
        }

        add_shortcode('qc_jarvis', array($this, 'jarvis_frontend_shortcode'));
        add_shortcode('qc_jarvis_widget', array($this, 'wsaj_widget_shortcode'));

        add_filter('pre_get_posts', array($this, 'jarvis_search_query'));

        add_filter('loop_shop_post_in', array($this, 'jarvis_price_filter'));
    }


    /**
     * Add a submenu item to the WooCommerce menu
     */
    public function admin_menu()
    {

        add_submenu_page('woocommerce',
            __('JARVIS-Lite', 'jarvis'),
            __('JARVIS-Lite', 'jarvis'),
            'manage_woocommerce',
            $this->id,
            array($this, 'admin_page'));

    }

    /**
     * Include backend required files.
     *
     * @return void
     */
    public function backend_includes()
    {
        include_once('classes/jarvis-class-language-builder.php');


    }

    /**
     * Include general required files.
     *
     * @return void
     */
    public function general_includes()
    {

        // Shortcode Class
        include_once('classes/shortcodes/class-shortcode-qc-jarvis.php');
        include_once('classes/shortcodes/class-widget-shortcode.php');

        //Widget Class
        include_once('classes/widgets/class-wc-widget-jarvis.php');
        include_once('classes/widgets/class-wc-widget-jarvis-recent-viewed-products.php');
        include_once('classes/widgets/class-wc-widget-jarvis-recent-sold-product.php');


    }


    /**
     * Include admin scripts
     */
    public function admin_scripts($hook)
    {
        global $woocommerce, $wp_scripts;

        $suffix = defined('SCRIPT_DEBUG') && SCRIPT_DEBUG ? '' : '.min';

        if (((!empty($_GET["page"])) && ($_GET["page"] == "jarvis")) || ($hook == "widgets.php")) {

            wp_enqueue_script('jquery');

            wp_enqueue_style('woocommerce_admin_styles', $woocommerce->plugin_url() . '/assets/css/admin.css');

            wp_register_style('jarvis-backend-style', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/admin-style.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('jarvis-backend-style');

            wp_register_style('font-awesome', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/font-awesome.min.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('font-awesome');

            wp_register_style('font-awesome-animation', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/font-awesome-animation.min.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('font-awesome-animation');

            wp_register_style('sweetalert2-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/sweetalert2.min.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('sweetalert2-css');

            wp_register_style('select2-style', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/select2.min.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('select2-style');

            /*wp_register_style('grideditor', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/grideditor.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('grideditor');*/

            wp_register_style('tabs-jarvis', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/tabs-jarvis.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('tabs-jarvis');

            /*wp_register_style('grideditor-demo', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/grideditor-demo.min.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('grideditor-demo');*/

            wp_register_script('cbpFWTabs', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/cbpFWTabs.js', basename(__FILE__)), array(), true);
            wp_enqueue_script('cbpFWTabs');

            wp_register_script('sweetatert2-js', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/sweetalert2.min.js', basename(__FILE__)), array(), true);
            wp_enqueue_script('sweetatert2-js');

            wp_register_script('modernizr-custom', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/modernizr.custom.js', basename(__FILE__)), array(), true);
            wp_enqueue_script('modernizr-custom');

            wp_register_script('jquery-ui', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jquery-ui.js', basename(__FILE__)), array('jquery'), true);
            wp_enqueue_script('jquery-ui');

            wp_register_script('jquery-grideditor', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jquery.grideditor.js', basename(__FILE__)), array('jquery'), true);
            wp_enqueue_script('jquery-grideditor');

            wp_register_script('select2', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/select2.full.min.js', basename(__FILE__)), array('jquery'), true);
            wp_enqueue_script('select2');


            /* wp_register_script('grideditor-demo', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jquery.grideditor-demo.min.js', basename(__FILE__)), array('jquery'), true);
             wp_enqueue_script('grideditor-demo');*/


            wp_register_script('bootstrap-js', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/bootstrap.js', basename(__FILE__)), array('jquery'), true);
            wp_enqueue_script('bootstrap-js');

            wp_register_style('qc-layout', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/qc-layout.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('qc-layout');

            wp_register_style('bootstrap-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/bootstrap.min.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('bootstrap-css');

            wp_register_script('jarvis-repeatable', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jquery.repeatable.js', basename(__FILE__)), array('jquery'));
            wp_enqueue_script('jarvis-repeatable');

            wp_register_script('jarvis-admin', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jarvis-admin.js', basename(__FILE__)), array('jquery'), true);
            wp_enqueue_script('jarvis-admin');

            wp_register_script('jquery-tiptip', $woocommerce->plugin_url() . '/assets/js/jquery-tiptip/jquery.tipTip' . $suffix . '.js', array('jquery'), $woocommerce->version, true);
            wp_enqueue_script('jquery-tiptip');

            wp_localize_script('jarvis-admin', 'ajax_object',
                array('ajax_url' => admin_url('admin-ajax.php')));

            $jarvis_params = array(
                'currency_symbol' => get_woocommerce_currency_symbol(),
                'default_button_text' => __("Find Them!", "jarvis"),

            );

            wp_localize_script('shop-jarvis', 'qc_jarvis_params', $jarvis_params);

        }

    }


    public function frontend_scripts()
    {
        global $woocommerce, $wp_scripts;

        if (get_option("permalink_structure") == "") {
            $shop_url = get_post_type_archive_link('product');
        } else {
            $shop_url = get_permalink(get_option('woocommerce_shop_page_id'));
        }

        $jarvis_params = array(
            'shop_url' => $shop_url,
            'jarvis_pop_up_form_effect' => get_option("jarvis_form_animation"),
            'position_x' => get_option('position_x'),
            'position_y' => get_option('position_y'),
            'disable_cart_item' => get_option('disable_cart_item'),
            'disable_jarvis_icon_animation' => get_option('disable_jarvis_icon_animation'),
            'jarvis_notifications' => json_encode(array(
                get_option('message_one'),
                get_option('message_two'),
                get_option('message_three'),
                get_option('message_four'),
                get_option('message_five'),
                get_option('message_six'),
                get_option('message_seven'),
                get_option('message_eight')
            ))
        );
        wp_register_script('jquery-ui', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jquery-ui.js', basename(__FILE__)), array('jquery'), true);
        wp_enqueue_script('jquery-ui');

        wp_register_script('classie-js', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/recomended-prod/classie.js', basename(__FILE__)), array('jquery'), QC_JARVIS_VERSION, true);
        wp_enqueue_script('classie-js');


        wp_register_script('dynamics-js', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/recomended-prod/dynamics.min.js', basename(__FILE__)), array('jquery'), QC_JARVIS_VERSION, true);
        wp_enqueue_script('dynamics-js');

        //wp_register_script('recomended-main', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/recomended-prod/main.js', basename(__FILE__)), array('jquery'), QC_JARVIS_VERSION, true);
        // wp_enqueue_script('recomended-main');

        wp_register_script('slimscroll-js', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jquery.slimscroll.min.js', basename(__FILE__)), array('jquery'), QC_JARVIS_VERSION, true);
        wp_enqueue_script('slimscroll-js');


        wp_register_script('animatedModal.min', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/animatedModal.min.js', basename(__FILE__)), array('jquery'), QC_JARVIS_VERSION, true);
        wp_enqueue_script('animatedModal.min');


        wp_register_script('jquery-cookie', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jquery.cookie.js', basename(__FILE__)), array('jquery'), QC_JARVIS_VERSION, true);
        wp_enqueue_script('jquery-cookie');

        wp_register_script('jarvis-typed', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jarvis-typed.js', basename(__FILE__)), array('jquery'), QC_JARVIS_VERSION, true);
        wp_enqueue_script('jarvis-typed');

        wp_register_script('jarvis-frontend', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jarvis-frontend.js', basename(__FILE__)), array('jquery', 'jquery-cookie'), QC_JARVIS_VERSION, true);
        wp_enqueue_script('jarvis-frontend');

        wp_register_script('jarvis-sell-notification', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jarvis-sell-notification.js', basename(__FILE__)), array('jquery'), QC_JARVIS_VERSION, true);
        wp_enqueue_script('jarvis-sell-notification');


        // wp_localize_script('jarvis-frontend', 'qc_jarvis_params', $jarvis_params);

        wp_localize_script('jarvis-frontend', 'ajax_object',
            array('ajax_url' => admin_url('admin-ajax.php'), 'image_path' => QC_JARVIS_IMG_URL));


        wp_register_style('qc-layout', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/qc-layout.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
        wp_enqueue_style('qc-layout');


        wp_register_style('animate-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/animate.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
        wp_enqueue_style('animate-css');


        wp_register_style('animatemodal-min-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/animatemodal.min.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
        wp_enqueue_style('animatemodal-min-css');


        // wp_register_style('recommended-prods-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/recommended-prods.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
        //wp_enqueue_style('recommended-prods-css');


        wp_register_style('jarvis-frontend', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/frontend-style.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
        wp_enqueue_style('jarvis-frontend');

        wp_register_style('jarvis-sell-notification-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/jarvis-sell-notification.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
        wp_enqueue_style('jarvis-sell-notification-css');
        if (get_option('jarvis_mode') == 'full') {
            //Tooltip for previous
            wp_register_style('tooltip-classic-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/tooltip-classic.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('tooltip-classic-css');
            $theme_name = preg_replace('/\\.[^.\\s]{3,4}$/', '', get_option('jarvis_theme'));
            if ($theme_name == 'theme-one') {
                wp_register_style('jarvis-template', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/jarvis-template-01.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
                wp_enqueue_style('jarvis-template');

            } else if ($theme_name == 'theme-two') {
                wp_register_style('jarvis-template', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/jarvis-template-02.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
                wp_enqueue_style('jarvis-template');

            } else if ($theme_name == 'theme-three') {
                wp_register_style('jarvis-template', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/jarvis-template-03.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
                wp_enqueue_style('jarvis-template');
            }


        } else if (get_option('jarvis_mode') == 'quickball') {
            //Tooltip for pinball
            wp_register_style('tooltip-pinball-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/tooltip-pinball.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('tooltip-pinball-css');
            wp_register_style('jarvis-template', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/pinball.css', basename(__FILE__)), '', QC_JARVIS_VERSION, 'screen');
            wp_enqueue_style('jarvis-template');
        }
        wp_localize_script('jarvis-frontend', 'qc_jarvis_params', $jarvis_params);

    }

    public function register_widgets()
    {

        register_widget('WC_Widget_jarvis');
        register_widget('WC_Widget_Jarvis_Recent_Viewed_Products');
        register_widget('WC_Widget_Jarvis_Recent_Sold_Product');

    }


    /**
     * Render the admin page
     */
    public function admin_page()
    {

        global $woocommerce;

        $action = 'admin.php?page=jarvis'; ?>
        <br>
        <form action="<?php echo esc_attr($action); ?>" method="POST" enctype="multipart/form-data">
            <div class="container form-container">
                <h2><?php echo __('JARVIS Control Panel', 'jarvis'); ?></h2>
                <div class="qc_get_pro">
                    <h2><a href="https://www.quantumcloud.com/products/woocommerce-shop-assistant-jarvis/">Get
                            The Professional Version</a></h2>
                    <p><a href="https://www.quantumcloud.com/">JARVIS is a project by Web Design Company
                            QuantumCloud</a></p>
                </div>
                <section class="jarvis-tab-container-inner">
                    <div class="tabs-jarvis tabs-jarvis-style-flip">
                        <nav>
                            <ul>
                                <li><a href="#section-flip-1"><i class="fa fa-toggle-on"></i><span> <strong>GENERAL SETTINGS</strong></span></a>
                                </li>
                                <li><a href="#section-flip-2"><i
                                                class="fa fa-search"></i><span> SEARCH SETTINGS</span></a></li>
                                <li><a href="#section-flip-3"><i class="fa fa-gear faa-spin animated"></i><span> ICONS & THEME</span></a>
                                </li>
                                <li><a href="#section-flip-4"><i class="fa fa-bell"></i><span> MESSAGE CENTER</span></a>
                                </li>
                                <li><a href="#section-flip-5"><i class="fa fa-shopping-cart"></i><span> ORDER NOTIFICATION</span></a>
                                </li>
                                <li><a href="#section-flip-7"><i
                                                class="fa fa-language"></i><span> LANGUAGE CENTER</span></a></li>
                                <li><a href="#section-flip-8"><i class="fa fa-code"></i><span> Custom CSS</span></a>
                                </li>
                                <li><a href="#section-flip-9"><i class="fa fa-line-chart"></i><span> Conversion Report </span></a>
                                </li>
                            </ul>
                        </nav>
                        <div class="content-wrap">
                            <section id="section-flip-1">
                                <table class="table table-bordered striped">
                                    <tbody>
                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">JARVIS Mode</p>
                                            <select class="jarvis_select_two qc-opt-dcs-font jarvis_mode"
                                                    name="jarvis_mode">
                                                <option disabled="disabled" value="vertical">Vertical Balls (Pro
                                                    Only)
                                                </option>
                                                <option disabled="disabled" value="slide">Slide Bar (Pro Only)
                                                </option>
                                                <option value="<?php echo get_option('jarvis_mode'); ?>"
                                                        selected="selected"><?php if (get_option('jarvis_mode') == 'quickball') {
                                                        echo "Quick Ball";
                                                    } else if (get_option('jarvis_mode') == 'full') {
                                                        echo "Full Page View (Legacy)";
                                                    } ?></option>
                                                <option value="quickball">Quick Ball</option>
                                                <option value="full">Full Page View (Legacy)</option>

                                            </select>

                                        </td>
                                    </tr>

                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Disable JARVIS
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <input id="disable_jarvis" type="checkbox" name="disable_jarvis" value="1" <?php echo(get_option('disable_jarvis') == '' ? 'checked' : ''); ?>>
                                                <label for="disable_jarvis">Disable JARVIS to load </label>
                                            </div>
                                        </td>
                                    </tr>

                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                This animation will appear when you click JARVIS icon on bottom
                                                right and close popup form
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <fieldset>
                                                    <select class="jarvis_select_two" name="jarvis_form_animation">
                                                        <option
                                                                value="<?php echo get_option('jarvis_form_animation'); ?>"
                                                                selected="selected"><?php echo get_option('jarvis_form_animation'); ?></option>
                                                        <optgroup label="Attention Seekers">
                                                            <option value="bounce">bounce</option>
                                                            <option value="flash">flash</option>
                                                            <option value="pulse">pulse</option>
                                                            <option value="rubberBand">rubberBand</option>
                                                            <option value="shake">shake</option>
                                                            <option value="swing">swing</option>
                                                            <option value="tada">tada</option>
                                                            <option value="wobble">wobble</option>
                                                            <option value="jello">jello</option>
                                                        </optgroup>

                                                        <optgroup label="Bouncing Entrances">
                                                            <option value="bounceIn">bounceIn</option>
                                                            <option value="bounceInDown">bounceInDown</option>
                                                            <option value="bounceInLeft">bounceInLeft</option>
                                                            <option value="bounceInRight">bounceInRight</option>
                                                            <option value="bounceInUp">bounceInUp</option>
                                                        </optgroup>

                                                        <optgroup label="Bouncing Exits">
                                                            <option value="bounceOut">bounceOut</option>
                                                            <option value="bounceOutDown">bounceOutDown</option>
                                                            <option value="bounceOutLeft">bounceOutLeft</option>
                                                            <option value="bounceOutRight">bounceOutRight</option>
                                                            <option value="bounceOutUp">bounceOutUp</option>
                                                        </optgroup>

                                                        <optgroup label="Fading Entrances">
                                                            <option value="fadeIn">fadeIn</option>
                                                            <option value="fadeInDown">fadeInDown</option>
                                                            <option value="fadeInDownBig">fadeInDownBig</option>
                                                            <option value="fadeInLeft">fadeInLeft</option>
                                                            <option value="fadeInLeftBig">fadeInLeftBig</option>
                                                            <option value="fadeInRight">fadeInRight</option>
                                                            <option value="fadeInRightBig">fadeInRightBig</option>
                                                            <option value="fadeInUp">fadeInUp</option>
                                                            <option value="fadeInUpBig">fadeInUpBig</option>
                                                        </optgroup>

                                                        <optgroup label="Fading Exits">
                                                            <option value="fadeOut">fadeOut</option>
                                                            <option value="fadeOutDown">fadeOutDown</option>
                                                            <option value="fadeOutDownBig">fadeOutDownBig</option>
                                                            <option value="fadeOutLeft">fadeOutLeft</option>
                                                            <option value="fadeOutLeftBig">fadeOutLeftBig</option>
                                                            <option value="fadeOutRight">fadeOutRight</option>
                                                            <option value="fadeOutRightBig">fadeOutRightBig</option>
                                                            <option value="fadeOutUp">fadeOutUp</option>
                                                            <option value="fadeOutUpBig">fadeOutUpBig</option>
                                                        </optgroup>

                                                        <optgroup label="Flippers">
                                                            <option value="flip">flip</option>
                                                            <option value="flipInX">flipInX</option>
                                                            <option value="flipInY">flipInY</option>
                                                            <option value="flipOutX">flipOutX</option>
                                                            <option value="flipOutY">flipOutY</option>
                                                        </optgroup>

                                                        <optgroup label="Lightspeed">
                                                            <option value="lightSpeedIn">lightSpeedIn</option>
                                                            <option value="lightSpeedOut">lightSpeedOut</option>
                                                        </optgroup>

                                                        <optgroup label="Rotating Entrances">
                                                            <option value="rotateIn">rotateIn</option>
                                                            <option value="rotateInDownLeft">rotateInDownLeft
                                                            </option>
                                                            <option value="rotateInDownRight">rotateInDownRight
                                                            </option>
                                                            <option value="rotateInUpLeft">rotateInUpLeft</option>
                                                            <option value="rotateInUpRight">rotateInUpRight</option>
                                                        </optgroup>

                                                        <optgroup label="Rotating Exits">
                                                            <option value="rotateOut">rotateOut</option>
                                                            <option value="rotateOutDownLeft">rotateOutDownLeft
                                                            </option>
                                                            <option value="rotateOutDownRight">rotateOutDownRight
                                                            </option>
                                                            <option value="rotateOutUpLeft">rotateOutUpLeft</option>
                                                            <option value="rotateOutUpRight">rotateOutUpRight
                                                            </option>
                                                        </optgroup>

                                                        <optgroup label="Sliding Entrances">
                                                            <option value="slideInUp">slideInUp</option>
                                                            <option value="slideInDown">slideInDown</option>
                                                            <option value="slideInLeft">slideInLeft</option>
                                                            <option value="slideInRight">slideInRight</option>

                                                        </optgroup>
                                                        <optgroup label="Sliding Exits">
                                                            <option value="slideOutUp">slideOutUp</option>
                                                            <option value="slideOutDown">slideOutDown</option>
                                                            <option value="slideOutLeft">slideOutLeft</option>
                                                            <option value="slideOutRight">slideOutRight</option>

                                                        </optgroup>

                                                        <optgroup label="Zoom Entrances">
                                                            <option value="zoomIn">zoomIn</option>
                                                            <option value="zoomInDown">zoomInDown</option>
                                                            <option value="zoomInLeft">zoomInLeft</option>
                                                            <option value="zoomInRight">zoomInRight</option>
                                                            <option value="zoomInUp">zoomInUp</option>
                                                        </optgroup>

                                                        <optgroup label="Zoom Exits">
                                                            <option value="zoomOut">zoomOut</option>
                                                            <option value="zoomOutDown">zoomOutDown</option>
                                                            <option value="zoomOutLeft">zoomOutLeft</option>
                                                            <option value="zoomOutRight">zoomOutRight</option>
                                                            <option value="zoomOutUp">zoomOutUp</option>
                                                        </optgroup>

                                                        <optgroup label="Specials">
                                                            <option value="hinge">hinge</option>
                                                            <option value="rollIn">rollIn</option>
                                                            <option value="rollOut">rollOut</option>
                                                        </optgroup>
                                                    </select>

                                                </fieldset>
                                            </div>
                                        </td>
                                    </tr>

                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Display JARVIS search
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <fieldset>
                                                    <input id="search" type="checkbox" name="jarvis_search"
                                                           value="jarvis_search" <?php echo(get_option('jarvis_search') == 'jarvis_search' ? 'checked' : ''); ?>>
                                                    <label for="search">Enable JARVIS search</label>


                                                </fieldset>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Display Cart Items On Pop Up Window
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <fieldset>
                                                    <input id="ham" type="checkbox" name="cart_products"
                                                           value="cart_products" <?php echo(get_option('cart_products') == 'cart_products' ? 'checked' : ''); ?>>
                                                    <label for="ham">Enable Cart Items</label>


                                                </fieldset>
                                            </div>
                                        </td>
                                    </tr>

                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Display Recommended Products On Pop Up Window <span class="badge">Pro version only</span>
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <input disabled="disabled" id="pepperoni" type="checkbox"
                                                       name="recommended_products"
                                                       value="">
                                                <label for="pepperoni">Enable Recommended Products</label>
                                            </div>
                                        </td>
                                    </tr>

                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Display Recent Products On Pop Up Window <span class="badge">Pro version only</span>
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <input disabled="disabled" id="mushrooms" type="checkbox"
                                                       name="recent_products"
                                                       value="recent_products">
                                                <label for="mushrooms">Enable Recent Products</label>
                                            </div>
                                        </td>
                                    </tr>

                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Repeat pop up notification through out user's stay on the website
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <input id="loop_notification" type="checkbox"
                                                       name="loop_notification"
                                                       value="1" <?php echo(get_option('loop_notification') == '1' ? 'checked' : ''); ?>>
                                                <label for="loop_notification">Enable Notification Loop</label>
                                            </div>
                                        </td>
                                    </tr>


                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Disable notifications
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <input id="disable_notification" type="checkbox"
                                                       name="disable_notification"
                                                       value="1" <?php echo(get_option('disable_notification') == '1' ? 'checked' : ''); ?>>
                                                <label for="disable_notification">Disable front end
                                                    notification</label>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Disable Cart Item Number
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <input id="disable_cart_item" type="checkbox"
                                                       name="disable_cart_item"
                                                       value="1" <?php echo(get_option('disable_cart_item') == '1' ? 'checked' : ''); ?>>
                                                <label for="disable_cart_item">Disable Cart Item Number on JARVIS
                                                    Icon</label>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Disable JARVIS Icon Animation
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <input id="disable_jarvis_icon_animation" type="checkbox"
                                                       name="disable_jarvis_icon_animation"
                                                       value="1" <?php echo(get_option('disable_jarvis_icon_animation') == '1' ? 'checked' : ''); ?>>
                                                <label for="disable_jarvis_icon_animation">Disable JARVIS Icon
                                                    Animation for Quick Ball</label>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Support Quickball on JARVIS
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <input id="support_quickball" type="checkbox"
                                                       name="support_quickball"
                                                       value="support_quickball" <?php echo(get_option('support_quickball') == 'support_quickball' ? 'checked' : ''); ?>>
                                                <label for="support_quickball">Enable SUPPORT quickball on
                                                    JARVIS</label>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr id="support_quickball_email_contianer">
                                        <td>
                                            <div>
                                                <p class="qc-opt-title-font">Support Email Address</p>
                                                <?php
                                                $url = get_site_url();
                                                $url = parse_url($url);
                                                $domain = $url['host'];
                                                $support_email = "support@" . $domain;
                                                ?>
                                                <input id="support_quickball_email" class="form-control"
                                                       type="email"
                                                       name="support_quickball_email"
                                                       value="<?php echo(get_option('support_quickball_email') != '' ? get_option('support_quickball_email') : $support_email); ?>">
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Add A Custom Quickball on JARVIS <span
                                                        class="badge">Pro version only</span>
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <input disabled="disabled" id="custom_quickball" type="checkbox"
                                                       name="custom_quickball"
                                                       value="custom_quickball">
                                                <label for="custom_quickball">Enable custom quickball on
                                                    JARVIS</label>
                                            </div>
                                        </td>
                                    </tr>

                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                <strong>Override Icon Position</strong>
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <?php
                                                $jarvis_position_x = get_option('position_x');
                                                if ((!isset($jarvis_position_x)) || ($jarvis_position_x == "")) {
                                                    $jarvis_position_x = __("0", "jarvis");
                                                }
                                                $jarvis_position_y = get_option('position_y');
                                                if ((!isset($jarvis_position_y)) || ($jarvis_position_y == "")) {
                                                    $jarvis_position_y = __("0", "jarvis");
                                                } ?>
                                                <p><span class="qc-opt-dcs-font">Offset </span>
                                                    <input type="number" class="qc-opt-dcs-font"
                                                           name="position_x"
                                                           id=""
                                                           value="<?php echo($jarvis_position_x); ?>"
                                                           placeholder="From Right In px">
                                                    <span class="qc-opt-dcs-font">px from Right of the Browser Window</span>
                                                </p>


                                                <p><span class="qc-opt-dcs-font">Offset </span>
                                                    <input type="number" class="qc-opt-dcs-font"
                                                           name="position_y"
                                                           id=""
                                                           value="<?php echo($jarvis_position_y); ?>"
                                                           placeholder="From Bottom In Px"> <span
                                                            class="qc-opt-dcs-font">px from Bottom of the Browser Window</span>
                                                </p>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">Select recommended products from dropdown to show them on front end <span class="badge">Pro version only</span></p>
                                            <div class="cxsc-settings-blocks">
                                                <?php $params = array('posts_per_page' => 10, 'post_type' => 'product');
                                                $wc_query = new WP_Query($params); ?>
                                                <select name="jarvis-recommended-products[]"
                                                        class="jarvis_select_two"
                                                        multiple="multiple" disabled>
                                                    <?php $_pf = new WC_Product_Factory(); ?>
                                                    <?php
                                                    if(!empty(unserialize(get_option('jarvis-recommended-products')))){
                                                    $products = unserialize(get_option('jarvis-recommended-products')); ?>
                                                    <?php foreach ($products as $id): ?>
                                                        <?php $product = $_pf->get_product($id); ?>
                                                        <option value="<?php echo $product->get_id(); ?>"
                                                                selected="selected"><?php echo $product->get_title(); ?></option>
                                                    <?php endforeach;
                                                    }
                                                    ?>
                                                    <?php if ($wc_query->have_posts()) : ?>
                                                        <?php while ($wc_query->have_posts()) :$wc_query->the_post(); ?>
                                                            <option
                                                                    value="<?php the_ID(); ?>" disabled>
                                                                <?php the_title(); ?>
                                                            </option>
                                                        <?php endwhile; ?>
                                                        <?php wp_reset_postdata(); ?>
                                                    <?php else: ?>
                                                        <li>
                                                            <?php _e('No Products'); ?>
                                                        </li>
                                                    <?php endif; ?>
                                                </select>
                                            </div>
                                        </td>
                                    </tr>
                                     <tr>
                                            <td>
                                                <p class="qc-opt-title-font"><strong>JARVIS</strong> Loading Control Options  <span class="badge">Pro version only</span></p>

                                                <div class="cxsc-settings-blocks">
                                                    <div class="row">
                                                        <div class="col-sm-4 text-right">
                                                            <span class="qc-opt-title-font">Show on Home Page</span>

                                                        </div>
                                                        <div class="col-sm-8">


                                                            <label class="radio-inline">
                                                                <input id="jarvis-show-home-page" type="radio"
                                                                       name="jarvis_show_home_page"
                                                                       value="on" <?php echo(get_option('jarvis_show_home_page') == 'on' ? 'checked' : ''); ?> disabled>
                                                                YES
                                                            </label>

                                                            <label class="radio-inline">
                                                                <input id="jarvis-show-home-page" type="radio"
                                                                       name="jarvis_show_home_page"
                                                                       value="off" <?php echo(get_option('jarvis_show_home_page') == 'off' ? 'checked' : ''); ?> disabled>
                                                                NO
                                                            </label>


                                                        </div>
                                                    </div>
                                                    <div class="row">
                                                        <div class="col-sm-4 text-right">
                                                            <span class="qc-opt-title-font">Show on Blog Posts</span>

                                                        </div>
                                                        <div class="col-sm-8">

                                                            <label class="radio-inline">
                                                                <input class="jarvis-show-posts" type="radio"
                                                                       name="jarvis_show_posts"
                                                                       value="on" <?php echo(get_option('jarvis_show_posts') == 'on' ? 'checked' : ''); ?> disabled>
                                                                YES
                                                            </label>

                                                            <label class="radio-inline">
                                                                <input class="jarvis-show-posts" type="radio"
                                                                       name="jarvis_show_posts"
                                                                       value="off" <?php echo(get_option('jarvis_show_posts') == 'off' ? 'checked' : ''); ?> disabled>
                                                                NO
                                                            </label>


                                                        </div>
                                                    </div>
                                                    <div class="row">
                                                        <div class="col-md-4 text-right">
                                                            <span class="qc-opt-title-font">Show on  Pages</span>

                                                        </div>
                                                        <div class="col-md-8">


                                                            <label class="radio-inline">
                                                                <input class="jarvis-show-pages" type="radio"
                                                                       name="jarvis_show_pages"
                                                                       value="on" <?php echo(get_option('jarvis_show_pages') == 'on' ? 'checked' : ''); ?> disabled>
                                                                All Pages
                                                            </label>

                                                            <label class="radio-inline">
                                                                <input class="jarvis-show-pages" type="radio"
                                                                       name="jarvis_show_pages"
                                                                       value="off" <?php echo(get_option('jarvis_show_pages') == 'off' ? 'checked' : ''); ?> disabled>
                                                                Selected Pages Only </label>

                                                           
                                                        </div>
                                                    </div>
                                                    <div class="row">
                                                        <div class="col-sm-4 text-right">
                                                            <span class="qc-opt-title-font">Show on WooCommerce</span>

                                                        </div>
                                                        <div class="col-sm-8">


                                                            <label class="radio-inline">
                                                                <input class="jarvis-show-woocommerce" type="radio"
                                                                       name="jarvis_show_woocommerce"
                                                                       value="on" <?php echo(get_option('jarvis_show_woocommerce') == 'on' ? 'checked' : ''); ?> disabled>
                                                                YES
                                                            </label>

                                                            <label class="radio-inline">
                                                                <input class="jarvis-show-woocommerce" type="radio"
                                                                       name="jarvis_show_woocommerce"
                                                                       value="off" <?php echo(get_option('jarvis_show_woocommerce') == 'off' ? 'checked' : ''); ?> disabled>
                                                                NO </label>


                                                        </div>
                                                    </div>
                                                    <br>
                                                    <span class="qc-opt-dcs-font">You can also load JARVIS on specific page/s only using shortcode: <strong>[jarvis_pro mode="vertical"]</strong> <span class="badge">Pro version only</span></span>

                                                </div>
                                            </td>
                                        </tr>


                                    </tbody>
                                </table>
                            </section>

                            <style type="text/css">
                                .jarvis_sentence_builder .span4 .add{
                                    margin-left: 15px !important;
                                    margin-top: 15px !important;
                                }
                            </style>
                            <section id="section-flip-2">
                                <table class="table table-bordered">
                                    <tbody>
                                    <tr>
                                        <p class="qc-opt-title-font">Construct your search query here. Add search
                                            terms here. You can connect each terms with natural language using the
                                            text fields</p>
                                        <td>
                                            <div class="cxsc-settings-blocks">
                                                <div class="phrase-example-holder">
                                                    <div class="phrase-example">
                                                        <div class="search-phrase btn alert alert-success"></div>
                                                        <div class="phrase-example-none pre-search-phrase">
                                                            <?php _e('Start building your search terms here', 'jarvis'); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                                <div class="cxsc-settings-block" id="cxsc-settings-block-general">
                                                    <?php jarvis_options_field_display('filter'); ?>
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Rename Search Button Text
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <?php
                                                $jarvis_button_text = get_option('jarvis-search-button-text');
                                                if ((!isset($jarvis_button_text)) || ($jarvis_button_text == "")) {
                                                    $jarvis_button_text = __("Find Them!", "jarvis");
                                                } ?>
                                                <input type="text" class="jarvis-search-button-text qc-opt-dcs-font"
                                                       name="jarvis-search-button-text"
                                                       id="jarvis-search-button-text"
                                                       value="<?php echo htmlentities($jarvis_button_text, ENT_QUOTES); ?>">
                                            </div>
                                        </td>
                                    </tr>

                                    <tr>
                                        <td>
                                            <p class="qc-opt-title-font">
                                                Show Search Result
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <ul class="">
                                                    <li><input type="radio"
                                                               name="jarvis_search_popup" <?php echo(get_option('jarvis_search_popup') == '1' ? 'checked' : ''); ?>
                                                               value="1">
                                                        <span class="qc-opt-dcs-font">In Pop Up Window</span>
                                                    </li>
                                                    <li><input disabled="disabled" type="radio"
                                                               name="jarvis_search_popup"
                                                               value="">
                                                        <span class="qc-opt-dcs-font">In Shop Page</span>
                                                    </li>
                                                </ul>
                                            </div>
                                        </td>
                                    </tr>
                                    </tbody>
                                </table>

                            </section>
                            <section id="section-flip-3">
                                <table class="table table-bordered striped">
                                    <tbody>
                                    <tr>
                                        <td><br><br>
                                            <ul class="radio-list">
                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-0.png"
                                                         alt=""> <input type="radio"
                                                                        name="jarvis_icon" <?php echo(get_option('jarvis_icon') == 'icon-0.png' ? 'checked' : ''); ?>
                                                                        value="icon-0.png">
                                                    <span class="qc-opt-dcs-font">Icon - 0</span>
                                                </li>


                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-1.png"
                                                         alt=""> <input type="radio"
                                                                        name="jarvis_icon" <?php echo(get_option('jarvis_icon') == 'icon-1.png' ? 'checked' : ''); ?>
                                                                        value="icon-1.png">
                                                    <span class="qc-opt-dcs-font">Icon - 1</span>
                                                </li>
                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-2.png"
                                                         alt=""> <input type="radio" name="jarvis_icon"
                                                                        value="icon-2.png" <?php echo(get_option('jarvis_icon') == 'icon-2.png' ? 'checked' : ''); ?>>
                                                    <span class="qc-opt-dcs-font">Icon - 2</span>
                                                </li>
                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-3.png"
                                                         alt=""> <input type="radio" name="jarvis_icon"
                                                                        value="icon-3.png" <?php echo(get_option('jarvis_icon') == 'icon-3.png' ? 'checked' : ''); ?>>
                                                    <span class="qc-opt-dcs-font">Icon - 3</span>
                                                </li>

                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-4.png"
                                                         alt=""> <input type="radio" name="jarvis_icon"
                                                                        value="icon-4.png" <?php echo(get_option('jarvis_icon') == 'icon-4.png' ? 'checked' : ''); ?>>
                                                    <span class="qc-opt-dcs-font">Icon - 4</span>
                                                </li>


                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-5.png"
                                                         alt=""> <input type="radio" name="jarvis_icon"
                                                                        value="icon-5.png" <?php echo(get_option('jarvis_icon') == 'icon-5.png' ? 'checked' : ''); ?>>
                                                    <span class="qc-opt-dcs-font">Icon - 5</span>
                                                </li>
                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-6.png"
                                                         alt=""> <input type="radio" name="jarvis_icon"
                                                                        value="icon-6.png" <?php echo(get_option('jarvis_icon') == 'icon-6.png' ? 'checked' : ''); ?>>
                                                    <span class="qc-opt-dcs-font">Icon - 6</span>
                                                </li>
                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-7.png"
                                                         alt=""> <input type="radio" name="jarvis_icon"
                                                                        value="icon-7.png" <?php echo(get_option('jarvis_icon') == 'icon-7.png' ? 'checked' : ''); ?>>
                                                    <span class="qc-opt-dcs-font">Icon - 7</span>
                                                </li>
                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-8.png"
                                                         alt=""> <input type="radio" name="jarvis_icon"
                                                                        value="icon-8.png" <?php echo(get_option('jarvis_icon') == 'icon-8.png' ? 'checked' : ''); ?>>
                                                    <span class="qc-opt-dcs-font">Icon - 8</span>
                                                </li>
                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-9.png"
                                                         alt=""> <input type="radio" name="jarvis_icon"
                                                                        value="icon-9.png" <?php echo(get_option('jarvis_icon') == 'icon-9.png' ? 'checked' : ''); ?>>
                                                    <span class="qc-opt-dcs-font">Icon -9</span>
                                                </li>
                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-10.png"
                                                         alt=""> <input type="radio" name="jarvis_icon"
                                                                        value="icon-10.png" <?php echo(get_option('jarvis_icon') == 'icon-10.png' ? 'checked' : ''); ?>>
                                                    <span class="qc-opt-dcs-font">Icon - 10</span>
                                                </li>
                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-11.png"
                                                         alt=""> <input type="radio" name="jarvis_icon"
                                                                        value="icon-11.png" <?php echo(get_option('jarvis_icon') == 'icon-11.png' ? 'checked' : ''); ?>>
                                                    <span class="qc-opt-dcs-font">Icon - 11</span>
                                                </li>
                                                <li><img src="<?php echo QC_JARVIS_IMG_URL; ?>/icon-12.png"
                                                         alt=""> <input type="radio" name="jarvis_icon"
                                                                        value="icon-12.png" <?php echo(get_option('jarvis_icon') == 'icon-12.png' ? 'checked' : ''); ?>>
                                                    <span class="qc-opt-dcs-font">Icon - 12</span>
                                                </li>


                                                <li>
                                                    <img src="<?php echo QC_JARVIS_IMG_URL; ?>/custom.png?<?php echo time(); ?>"
                                                         alt=""> <input type="radio" name="jarvis_icon"
                                                                        value="custom.png" <?php echo(get_option('jarvis_icon') == 'custom.png' ? 'checked' : ''); ?>>

                                                    <span class="qc-opt-dcs-font">Custom Icon</span>
                                                </li>


                                            </ul>
                                        </td>
                                    </tr>

                                    <tr>
                                        <td><p class="qc-opt-title-font">
                                                Upload custom Icon <span class="badge">Pro version only</span>
                                            </p>
                                            <div class="cxsc-settings-blocks">
                                                <p class="qc-opt-dcs-font"><?php echo __('Select file to upload') ?>
                                                    <input disabled="disabled" type="file"
                                                           name="custom_icon"
                                                           id="custom_icon"
                                                           size="35"
                                                           class=""/>
                                                    <label class="qc-opt-dcs-font" for="pepperoni">Upload Custom
                                                        Icon</label>
                                            </div>
                                        </td>
                                    </tr>


                                    <tr>
                                        <td>
                                            <div class="row">
                                                <div class="col-sm-3">
                                                    <img class="thumbnail theme_prev"
                                                         src="<?php echo QC_JARVIS_IMG_URL; ?>/theme-one.jpg"
                                                         alt="">
                                                    <input type="radio"
                                                           name="jarvis_theme" <?php echo(get_option('jarvis_theme') == 'theme-one.jpg' ? 'checked' : ''); ?>
                                                           value="theme-one.jpg">
                                                    <strong class="qc-opt-dcs-font">Theme One</strong>

                                                </div>
                                                <div class="col-sm-3">
                                                    <img class="thumbnail theme_prev"
                                                         src="<?php echo QC_JARVIS_IMG_URL; ?>/theme-two.jpg"
                                                         alt=""> <input type="radio"
                                                                        name="jarvis_theme" <?php echo(get_option('jarvis_theme') == 'theme-two.jpg' ? 'checked' : ''); ?>
                                                                        value="theme-two.jpg">
                                                    <strong class="qc-opt-dcs-font">Theme Two</strong>

                                                </div>
                                                <div class="col-sm-3">
                                                    <img class="thumbnail theme_prev"
                                                         src="<?php echo QC_JARVIS_IMG_URL; ?>/theme-three.jpg"
                                                         alt="">
                                                    <input type="radio" name="jarvis_theme"
                                                           value="theme-three.jpg" <?php echo(get_option('jarvis_theme') == 'theme-three.jpg' ? 'checked' : ''); ?>>
                                                    <strong class="qc-opt-dcs-font">Theme Three</strong>
                                                </div>

                                            </div>


                                        </td>
                                    </tr>
                                    </tbody>
                                </table>
                            </section>
                            <section id="section-flip-4">
                                <p class="qc-opt-dcs-font">Global Notification Delay Time :
                                    <input name="global_notification_delay_time"
                                           type="text"
                                           class="text-control input-sm"
                                           value="<?php echo (get_option('global_notification_delay_time')) ? get_option('global_notification_delay_time') : ''; ?>">
                                    in sec </p>
                                <hr>
                                <div class="row">
                                    <div class="col-xs-12">
                                        <h3 class="alert alert-success qc-opt-title-font">SET NOTIFICATIONS FOR
                                            JARVIS</h3>
                                    </div>
                                </div>


                                <div class="row">
                                    <div class="col-xs-12">
                                        <p class="qc-opt-description"></p>
                                        <div class="cxsc-settings-blocks">
                                            <p>
                                                <?php $settings = array('textarea_name' =>
                                                    'message_six',
                                                    'textarea_rows' => 20,
                                                    'editor_height' => 100,
                                                    'editor_class' => 'customNotificationClass',
                                                    'media_buttons' => false
                                                );

                                                wp_editor(get_option('message_six'), 'message_six', $settings); ?>
                                        </div>
                                        <br>
                                        <p class="qc-opt-dcs-font">Message display duration time</p>
                                        <p>
                                            <input class="form-control input-sm" type="text"
                                                   value="<?php echo get_option('notification_delay_six'); ?>"
                                                   name="notification_delay_six">
                                            <strong class="qc-opt-dcs-font"> in second</strong></p>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-xs-12">
                                        <p class="qc-opt-description"></p>
                                        <div class="cxsc-settings-blocks">
                                            <p>
                                                <?php $settings = array('textarea_name' =>
                                                    'message_seven',
                                                    'textarea_rows' => 20,
                                                    'editor_height' => 100,
                                                    'editor_class' => 'customNotificationClass',
                                                    'media_buttons' => false
                                                );

                                                wp_editor(get_option('message_seven'), 'message_seven', $settings); ?>
                                        </div>
                                        <br>
                                        <p class="qc-opt-dcs-font">Message display duration time</p>
                                        <p>
                                            <input class="form-control input-sm" type="text"
                                                   value="<?php echo get_option('notification_delay_seven'); ?>"
                                                   name="notification_delay_seven">
                                            <strong class="qc-opt-dcs-font"> in second</strong></p>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-xs-12">
                                        <p class="qc-opt-description"></p>
                                        <div class="cxsc-settings-blocks">
                                            <p>
                                                <?php $settings = array('textarea_name' =>
                                                    'message_eight',
                                                    'textarea_rows' => 20,
                                                    'editor_height' => 100,
                                                    'editor_class' => 'customNotificationClass',
                                                    'media_buttons' => false
                                                );

                                                wp_editor(get_option('message_eight'), 'message_eight', $settings); ?>
                                        </div>
                                        <br>
                                        <p class="qc-opt-dcs-font">Message display duration time</p>
                                        <p>
                                            <input class="form-control input-sm" type="text"
                                                   value="<?php echo get_option('notification_delay_eight'); ?>"
                                                   name="notification_delay_eight">
                                            <strong class="qc-opt-dcs-font"> in second</strong></p>
                                    </div>
                                </div>
                            </section>

                            <section id="section-flip-5">
                                <div class="top-section">
                                    <div class="row">
                                        <div class="col-xs-12">
                                            <p class="qc-opt-dcs-font">Sale alerts will help you sell more products
                                                by creating an urgency
                                                among prospective buyers by showing who else just brought products
                                                from your store. If your store is not so busy, you can create
                                                artificial sell alerts below: </p>
                                            <p class="alert alert-success qc-opt-dcs-font ">GENERATE ARTIFICIAL
                                                SALE</p>

                                            <?php $artificial_sale_data = json_decode(get_option('artificial_orders_val')); ?>
                                            <p class="qc-opt-dcs-font"> Enable Sale Notification <span
                                                        class="badge">Pro version only</span></p>
                                            <div class="cxsc-settings-blocks">
                                                <fieldset>
                                                    <input disabled="disabled" id="fake_sale_notification"
                                                           type="checkbox"
                                                           name="fake_sale_notification"
                                                           value="fake_sale_notification" <?php echo(get_option('fake_sale_notification') == 'fake_sale_notification' ? 'checked' : ''); ?>>
                                                    <label for="fake_sale_notification">Disable Notification</label>
                                                </fieldset>
                                            </div>
                                            <br>
                                            <p class="qc-opt-dcs-font">Enable sale notification in mobile <span
                                                        class="badge">Pro version only</span></p>
                                            <div class="cxsc-settings-blocks">
                                                <fieldset>
                                                    <input disabled="disabled" id="sell_notification_off_mobile"
                                                           type="checkbox"
                                                           name="sell_notification_off_mobile"
                                                           value="sell_notification_off_mobile" <?php echo(get_option('sell_notification_off_mobile') == 'sell_notification_off_mobile' ? 'checked' : ''); ?>>
                                                    <label for="sell_notification_off_mobile">Disable sell
                                                        notification in
                                                        mobile</label>
                                                </fieldset>
                                            </div>
                                            <br>
                                            <p class="qc-opt-dcs-font"> Enable Sale Notification Sound <span
                                                        class="badge">Pro version only</span></p>
                                            <div class="cxsc-settings-blocks">
                                                <fieldset>
                                                    <input disabled="disabled" id="notification_sound"
                                                           type="checkbox"
                                                           name="fake_sale_notification_sound"
                                                           value="fake_sale_notification_sound" <?php echo(get_option('fake_sale_notification_sound') == 'fake_sale_notification_sound' ? 'checked' : ''); ?>>
                                                    <label for="notification_sound">Disable Notification
                                                        Sound</label>
                                                </fieldset>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row">
                                        <div class="col-xs-12">
                                            <p qc-opt-dcs-font>Global notification delay time for artificial sale :
                                                <input disabled="disabled"
                                                       name="global_fake_sale_delay_time"
                                                       type="text"
                                                       class="text-control input-sm"
                                                       value="<?php echo (get_option('global_fake_sale_delay_time')) ? get_option('global_fake_sale_delay_time') : ''; ?>">
                                                in sec </p>
                                        </div>
                                    </div>
                                </div>
                                <!--top-section-->

                                <div class="block-section">
                                    <?php if (!empty($artificial_sale_data)) { ?>
                                        <?php foreach ($artificial_sale_data as $sale_data) : ?>
                                            <div class="block-inner">
                                                <div class="col-xs-12 text-right">
                                                    <button disabled="disabled" type="button"
                                                            class="btn btn-danger qcld-remove-on-item "><i
                                                                class="fa fa-times" aria-hidden="true"></i>
                                                        Remove
                                                    </button>
                                                </div>
                                                <div class="row">
                                                    <div class="col-xs-12">
                                                        <?php $products = $sale_data->product_id; ?>
                                                        <p class="qc-opt-title-font">Select a product <span
                                                                    class="badge">Pro version only</span></p>
                                                        <div class="cxsc-settings-blocks">
                                                            <?php $params = array('posts_per_page' => -1, 'post_type' => 'product');
                                                            $wc_query = new WP_Query($params); ?>
                                                            <select disabled="disabled" name="fake-product-one"
                                                                    class="jarvis_select_two">
                                                                <?php $_pf = new WC_Product_Factory(); ?>
                                                                <?php $product = $_pf->get_product($products); ?>
                                                                <option value="" selected="selected">Select
                                                                    product(s)
                                                                </option>
                                                                <?php if ($wc_query->have_posts()) : ?>
                                                                    <?php while ($wc_query->have_posts()) :$wc_query->the_post(); ?>
                                                                        <option value="<?php the_ID(); ?>">
                                                                            <?php the_title(); ?>
                                                                        </option>
                                                                    <?php endwhile; ?>
                                                                    <?php wp_reset_postdata(); ?>
                                                                <?php else: ?>
                                                                    <li>
                                                                        <?php _e('No Products'); ?>
                                                                    </li>
                                                                <?php endif; ?>
                                                            </select>
                                                        </div>
                                                    </div>
                                                </div>
                                                <div class="row">
                                                    <div class="col-xs-12">
                                                        <p class="qc-opt-description"></p>
                                                        <div class="cxsc-settings-blocks">
                                                            <p class="qc-opt-dcs-font">Customer Name</p>
                                                            <input disabled="disabled" type="text"
                                                                   class="form-control customer-name"
                                                                   name="customer_name_one"
                                                                   value=""
                                                                   placeholder="Customer Name">
                                                            <p class="qc-opt-dcs-font">Customer Address</p>
                                                            <textarea disabled="disabled"
                                                                      name="customer_address_one"
                                                                      class="form-control customer-address"
                                                                      cols="10"
                                                                      rows="2"><?php echo $sale_data->customer_address; ?></textarea>
                                                            <p class="qc-opt-dcs-font">Fake Sale Notification
                                                                Duration Time</p>
                                                            <p class="qc-opt-dcs-font">
                                                                <input disabled="disabled"
                                                                       class="form-control input-sm notification-duration"
                                                                       type="text"
                                                                       value="<?php echo $sale_data->notification_duration; ?>"
                                                                       name="fake_sale_notification_delay_one">
                                                                <strong> in
                                                                    second</strong></p>
                                                        </div>
                                                        <br>
                                                    </div>
                                                </div>
                                            </div>
                                        <?php endforeach; ?>

                                    <?php } else { ?>
                                        <div class="block-inner">
                                            <div class="row">
                                                <div class="col-xs-12">
                                                    <p class="qc-opt-title-font">Select a product <span
                                                                class="badge">Pro version only</span></p>
                                                    <div class="cxsc-settings-blocks">
                                                        <?php $params = array('posts_per_page' => -1, 'post_type' => 'product');
                                                        $wc_query = new WP_Query($params); ?>
                                                        <select disabled="disabled" name="fake-product-one"
                                                                class="jarvis_select_two">
                                                            <option value="">Select a product</option>
                                                        </select>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="row">
                                                <div class="col-xs-12">
                                                    <p class="qc-opt-description"></p>
                                                    <div class="cxsc-settings-blocks">
                                                        <p class="qc-opt-dcs-font">Customer Name</p>
                                                        <input disabled="disabled" type="text"
                                                               class="form-control customer-name"
                                                               name=""
                                                               value=""
                                                               placeholder="Customer Name">
                                                        <p class="qc-opt-dcs-font"><strong>Customer Address</strong>
                                                        </p>
                                                        <textarea disabled="disabled" name=""
                                                                  class="form-control customer-address"
                                                                  cols="30"
                                                                  rows="2"></textarea>
                                                        <p class="qc-opt-dcs-font">Fake Sale Notification Duration
                                                            Time</p>
                                                        <p class="qc-opt-dcs-font">
                                                            <input disabled="disabled"
                                                                   class="form-control input-sm notification-duration"
                                                                   type="text"
                                                                   value=""
                                                                   name="fake_sale_notification_delay_one">
                                                            <strong> in second</strong>
                                                        </p>
                                                    </div>
                                                    <br>
                                                </div>
                                            </div>
                                        </div>


                                    <?php } ?>
                                    <!-- block inner -->
                                </div>
                                <!--block-section-->
                                <div class="row">
                                    <div class="col-sm-6 text-left">
                                        <button class="btn btn-success " type="button" id="" disabled="disabled">
                                            Save Order Notification
                                        </button>
                                        <input type="hidden" id="artificial-orders-val"
                                               name="artificial_orders_val">

                                    </div>
                                    <div class="col-sm-6 text-right">
                                        <button class="btn btn-warning" type="button" disabled="disabled" id=""><i
                                                    class="fa fa-plus" aria-hidden="true"></i>
                                            Add More
                                        </button>

                                    </div>
                                </div>
                            </section>
                            <section id="section-flip-7">
                                <tr>
                                    <td><p class="qc-opt-title-font"><strong>Translate various titles for popup
                                                view</strong></p>
                                        <div class="cxsc-settings-blocks">
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font"> Recently Viewed Products - Left Blank
                                                    For Default Value</p>
                                                <p class="qc-opt-title-font">Global Font Size For Widgets : <input
                                                            name="global_widget_font_size"
                                                            type="text"
                                                            class="text-control input-sm qc-opt-dcs-font"
                                                            value="<?php echo (get_option('global_widget_font_size')) ? get_option('global_widget_font_size') : ''; ?>">
                                                    in px
                                                </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="recently_viewed_products_title"
                                                       value="<?php echo (get_option('recently_viewed_products_title')) ? get_option('recently_viewed_products_title') : ''; ?>"
                                                       placeholder="Recently Viewed Products">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-title-font">
                                                    How May I Assist You Today - Left Blank For Default
                                                    Value
                                                </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="assist_today_title"
                                                       value="<?php echo (get_option('assist_today_title')) ? get_option('assist_today_title') : ''; ?>"
                                                       placeholder="How May I Assist You Today">
                                            </div>

                                            <div class="form-group">
                                                <p class="qc-opt-title-font">
                                                    Recommended Products
                                                </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="recommended_products_title"
                                                       value="<?php echo (get_option('recommended_products_title')) ? get_option('recommended_products_title') : ''; ?>"
                                                       placeholder="Recommended Products">
                                            </div>

                                            <div class="form-group">
                                                <p class="qc-opt-title-font">
                                                    User 'From' 'Purchased a'
                                                </p>

                                                <div class="input-group">
                                                    <input name="user_from_title" type="text"
                                                           class="form-control qc-opt-dcs-font"
                                                           value="<?php echo (get_option('user_from_title')) ? get_option('user_from_title') : ''; ?>"/>
                                                    <span class="input-group-addon">-</span>
                                                    <input name="user_purchased_a_title" type="text"
                                                           class="form-control qc-opt-dcs-font"
                                                           value="<?php echo (get_option('user_purchased_a_title')) ? get_option('user_purchased_a_title') : ''; ?>"/>
                                                </div>
                                            </div>


                                        </div>
                                        <br>
                                    </td>


                                </tr>
                                <tr>
                                    <td>
                                        <div id="jarvis-ajax-search-message">
                                            <p class="qc-opt-title-font">Message settings for <strong>In Pop Up
                                                    Window </strong></p>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">if products found </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="p_scs_msg"
                                                       value="<?php echo(get_option('p_scs_msg') != '' ? get_option('p_scs_msg') : 'Great! We have these products.'); ?>">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">if products not found </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="p_fail_msg"
                                                       value="<?php echo(get_option('p_fail_msg') != '' ? get_option('p_fail_msg') : 'Oops! Nothing matches your exact criteria. How about selecting some different options?'); ?>">
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <td>
                                        <div id="jarvis-ajax-search-message">
                                            <p class="qc-opt-title-font">Message settings for <strong> Recently Sold
                                                    Products </strong></p>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">Recently Sold Products </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="last_sold_product_title"
                                                       value="<?php echo(get_option('last_sold_product_title') != '' ? get_option('last_sold_product_title') : 'Recently Sold Products'); ?>">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">No recently sold products found </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="no_last_sold_product"
                                                       value="<?php echo(get_option('no_last_sold_product') != '' ? get_option('no_last_sold_product') : 'No recently sold products found.'); ?>">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">from </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="last_sold_from"
                                                       value="<?php echo(get_option('last_sold_from') != '' ? get_option('last_sold_from') : 'from'); ?>">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">Guest from </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="last_sold_guest_from"
                                                       value="<?php echo(get_option('last_sold_guest_from') != '' ? get_option('last_sold_guest_from') : 'Guest from'); ?>">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">just purchased </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="last_sold_just_purchased"
                                                       value="<?php echo(get_option('last_sold_just_purchased') != '' ? get_option('last_sold_just_purchased') : 'just purchased'); ?>">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">purchased a </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="last_sold_purchased_a"
                                                       value="<?php echo(get_option('last_sold_purchased_a') != '' ? get_option('last_sold_purchased_a') : 'purchased a'); ?>">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">Last sold Time</p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="last_sold_time"
                                                       value="<?php echo(get_option('last_sold_time') != '' ? get_option('last_sold_time') : 'About 20 minutes  ago'); ?>">
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <td>
                                        <div id="jarvis-ajax-search-message">
                                            <p class="qc-opt-title-font">Message settings for <strong> Recently
                                                    Viewed Products </strong></p>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">Add to cart</p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="recently_viewed_add_to_cart"
                                                       value="<?php echo(get_option('recently_viewed_add_to_cart') != '' ? get_option('recently_viewed_add_to_cart') : 'Add to cart'); ?>">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">View Detail </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="recently_viewed_details"
                                                       value="<?php echo(get_option('recently_viewed_details') != '' ? get_option('recently_viewed_details') : 'View Detail'); ?>">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">You have not viewed any products yet
                                                    ! </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="recently_viewed_no_product_founnd"
                                                       value="<?php echo(get_option('recently_viewed_no_product_founnd') != '' ? get_option('recently_viewed_no_product_founnd') : 'You have not viewed any products yet !'); ?>">
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <td>
                                        <div id="jarvis-ajax-search-message">
                                            <p class="qc-opt-title-font">Message settings for <strong>
                                                    Cart </strong></p>

                                            <div class="form-group">
                                                <p class="qc-opt-title-font">Your Basket - Left Blank For Default
                                                    Value </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="your_basket_title"
                                                       value="<?php echo (get_option('your_basket_title')) ? get_option('your_basket_title') : 'Your Basket'; ?>">
                                            </div>

                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">You do not have any products in the
                                                    cart </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="cart_no_product_found"
                                                       value="<?php echo(get_option('cart_no_product_found') != '' ? get_option('cart_no_product_found') : 'You do not have any products in the cart'); ?>">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">Total Price</p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="cart_total_price"
                                                       value="<?php echo(get_option('cart_total_price') != '' ? get_option('cart_total_price') : 'Total Price'); ?>">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">Cart </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="cart_cart_link"
                                                       value="<?php echo(get_option('cart_cart_link') != '' ? get_option('cart_cart_link') : 'Cart'); ?>">
                                            </div>
                                            <div class="form-group">
                                                <p class="qc-opt-dcs-font">Checkout </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="cart_checkout_link"
                                                       value="<?php echo(get_option('cart_checkout_link') != '' ? get_option('cart_checkout_link') : 'Checkout'); ?>">
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <td>
                                        <div id="jarvis-ajax-search-message">
                                            <p class="qc-opt-title-font">Message settings for <strong>
                                                    Quick Ball </strong></p>

                                            <div class="form-group">
                                                <p class="qc-opt-title-font">Questions or Comments? Contact Us Value </p>
                                                <input type="text" class="form-control qc-opt-dcs-font"
                                                       name="jarvis_support_form_title"
                                                       value="<?php echo (get_option('jarvis_support_form_title')) ? get_option('jarvis_support_form_title') : 'Questions or Comments? Contact Us'; ?>">
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                            </section>
                            <section id="section-flip-8">
                                <div class="top-section">
                                    <div class="row">
                                        <div class="col-xs-12">
                                            <p class="qc-opt-dcs-font">You can paste or write your custom css
                                                here.</p>
                                            <textarea name="custom_global_css"
                                                      class="form-control custom-global-css"
                                                      cols="10"
                                                      rows="4"><?php echo get_option('custom_global_css'); ?></textarea>
                                        </div>
                                    </div>
                                </div>
                            </section>

    <style>
        .qcld_jarvis_wrap { background: #fff; box-shadow: 0px 0px 25px -5px rgba(0,0,0,0.45); padding: 20px; border-radius: 10px; min-height: 450px }
        .qcld_jarvis_wrap h2 { padding-left: 0; font-weight: bold;color:#333 !important;}
        .qcld_jarvis_wrap p { padding-left: 0; font-size:16px; font-weight: 400; }
        .qcld_jarvis_wrap p a{ text-decoration: none }
    </style>
                            <section id="section-flip-9">
                                <div class="top-section">
                                    <div class="row">
                                        <div class="col-xs-12">
                                            <!-- <p class="qc-opt-dcs-font"> Conversion Report </p> -->

                                        <div class="qcld_jarvis_wrap">
                                            <h2> Conversion Report </h2>
                                            <p> Conversion Report is a Pro Version Feature. Please <a href="https://www.quantumcloud.com/products/woocommerce-shop-assistant-jarvis/" target="_blank"><span style="font-weight: bold; color: #FCB214">Upgrade to the Pro Version. </span> </a></p>

                                            <div id="qcld_express_content">                  
                                              <!-- Promo Block 1 -->
                                              <div style="margin-top: 20px;"> <div class="qc-promo-plugins" ><img src="<?php echo QCLD_EXPRESS_IMG_URL ?>/qc-logo-full.png" alt="QuantumCloud Logo"><br><br><hr><br><a href="http://www.quantumcloud.com" target="_blank" style="margin-left: 65px;">QuantumCloud</a></div> </div>
                                            </div>
                                        </div>
                                        </div>
                                    </div>
                                </div>
                            </section>
                        </div><!-- /content -->
                    </div><!-- /tabs-jarvis -->
                    <hr>
                    <div class="row">
                        <div class="text-left col-sm-3 col-sm-offset-3">
                            <input type="button" class="btn btn-warning submit-button"
                                   id="jarvis-reset-options-default"
                                   value="<?php _e('Reset all options to default', 'jarvis'); ?>"/>
                        </div>
                        <div class="text-right col-sm-6">
                            <input type="hidden" name="action" value="jarvis-submitted"/>
                            <input type="submit" class="btn btn-primary submit-button" name="submit"
                                   id="submit" value="<?php _e('Save Settings', 'jarvis'); ?>"/>
                        </div>
                    </div>

                </section>
            </div>


            <?php wp_nonce_field('jarvis'); ?>
        </form>

        <?php

    }

    /**
     * Create shortcode for Jarvis
     */
    public function jarvis_frontend_shortcode($atts)
    {

        global $woocommerce;

        if (class_exists('WC_Shortcodes') && method_exists('WC_Shortcodes', 'shortcode_wrapper')) {
            return WC_Shortcodes::shortcode_wrapper(array('QC_Shortcode_Jarvis', 'output'), $atts);
        } else {
            return $woocommerce->shortcode_wrapper(array('QC_Shortcode_Jarvis', 'output'), $atts);
        }
    }


    public function wsaj_widget_shortcode($atts)
    {

        global $woocommerce;

        if (class_exists('WC_Shortcodes') && method_exists('WC_Shortcodes', 'shortcode_wrapper')) {
            return WC_Shortcodes::shortcode_wrapper(array('QC_Widget_Jarvis', 'output'), $atts);
        } else {
            return $woocommerce->shortcode_wrapper(array('QC_Widget_Jarvis', 'output'), $atts);
        }
    }

    /**
     * Save Options
     */


    function jarvis_save_options()
    {


        global $woocommerce;
        if (isset($_POST['_wpnonce']) && $_POST['_wpnonce']) {


            wp_verify_nonce($_POST['_wpnonce'], 'jarvis');


            // Check if the form is submitted or not

            if (isset($_POST['submit'])) {

                if (isset($_POST["jarvis-terms-fields"])) {

                    $filter_fields = $_POST["jarvis-terms-fields"];
                    if ($filter_fields) {
                        $formatted_filter_fields = array();
                        foreach ($filter_fields as $filter_field) {
                            if ($filter_field["filter"] != "") {
                                $formatted_filter_fields[] = stripslashes_deep(array_map("wc_clean", $filter_field));
                            }
                        }
                        $serialized_filter_fields = serialize($formatted_filter_fields);

                        update_option('jarvis-terms-fields', $serialized_filter_fields);

                    }
                } else {
                    if (($_GET["page"] == "jarvis") && (isset($_POST["action"]))) {
                        delete_option('jarvis-terms-fields');
                    }
                }

                if (isset($_POST["jarvis-search-button-text"])) {
                    $button_text = stripslashes(($_POST["jarvis-search-button-text"]));
                    update_option('jarvis-search-button-text', $button_text);
                }
                if (isset($_POST["position_x"])) {
                    $position_x = sanitize_text_field($_POST["position_x"]);
                    update_option('position_x', $position_x);
                }
                if (isset($_POST["position_y"])) {
                    $position_y = sanitize_text_field($_POST["position_y"]);
                    update_option('position_y', $position_y);
                }


                /**
                 * ARTIFICIAL SALE NOTIFICATION DELAYS
                 */


                $artificial_orders_val = stripslashes($_POST['artificial_orders_val']);
                if (!empty($artificial_orders_val)) {
                    update_option('artificial_orders_val', $artificial_orders_val);
                }


                /**
                 * MESSAGE NOTIFICATION DELAY
                 */


                if (isset($_POST["notification_delay_six"])) {
                    $notification_delay_six = sanitize_text_field(($_POST["notification_delay_six"]));
                    update_option('notification_delay_six', $notification_delay_six);
                }
                if (isset($_POST["notification_delay_seven"])) {
                    $notification_delay_seven = sanitize_text_field(($_POST["notification_delay_seven"]));
                    update_option('notification_delay_seven', $notification_delay_seven);
                }

                if (isset($_POST["notification_delay_eight"])) {
                    $notification_delay_eight = sanitize_text_field(($_POST["notification_delay_eight"]));
                    update_option('notification_delay_eight', $notification_delay_eight);
                }

                if (isset($_POST["disable_jarvis"])) {
                    update_option('disable_jarvis', '');
                }else{
                    update_option('disable_jarvis', '1');
                }

                if (isset($_POST["jarvis_mode"])) {
                    $jarvis_mode = sanitize_text_field(($_POST["jarvis_mode"]));
                    update_option('jarvis_mode', $jarvis_mode);
                }else{
                    update_option('jarvis_mode', '');
                }
                if (isset($_POST["disable_cart_item"])) {
                    $disable_cart_item = sanitize_text_field(($_POST["disable_cart_item"]));
                    update_option('disable_cart_item', $disable_cart_item);
                }else{
                    update_option('disable_cart_item', '');
                }

                if (isset($_POST["disable_jarvis_icon_animation"])) {
                $disable_jarvis_icon_animation = sanitize_text_field(($_POST["disable_jarvis_icon_animation"]));
                update_option('disable_jarvis_icon_animation', $disable_jarvis_icon_animation);
                }else{
                    update_option('disable_jarvis_icon_animation', '');
                }
                /**
                 * FAKE SALE
                 */

                if (isset($_POST["customer_name_one"])) {
                    $customer_name_one = (($_POST["customer_name_one"]));
                    update_option('customer_name_one', $customer_name_one);
                }else{
                    update_option('customer_name_one', '');                    
                }

                if (isset($_POST["customer_address_one"])) {
                    $customer_address_one = (($_POST["customer_address_one"]));
                    update_option('customer_address_one', $customer_address_one);
                }else{
                    update_option('customer_address_one', '');
                }


                if (isset($_POST["customer_name_two"])) {
                    $customer_name_two = (($_POST["customer_name_two"]));
                    update_option('customer_name_two', $customer_name_two);
                }else{
                    update_option('customer_name_two', '');                    
                }

                if (isset($_POST["customer_address_two"])) {
                    $customer_address_two = (($_POST["customer_address_two"]));
                    update_option('customer_address_two', $customer_address_two);
                }else{
                    update_option('customer_address_two', '');

                }

                if (isset($_POST["customer_name_three"])) {
                    $customer_name_three = (($_POST["customer_name_three"]));
                    update_option('customer_name_three', $customer_name_three);
                }else{
                    update_option('customer_name_three', '');

                }


                if (isset($_POST["customer_address_three"])) {
                    $customer_address_three = (($_POST["customer_address_three"]));
                    update_option('customer_address_three', $customer_address_three);
                }else{
                    update_option('customer_address_three', '');
                    
                }


                /**
                 * FRONT END TITLE
                 */

                $recently_viewed_products_title = (($_POST["recently_viewed_products_title"]));
                update_option('recently_viewed_products_title', sanitize_text_field($recently_viewed_products_title));

                $assist_today_title = (($_POST["assist_today_title"]));
                update_option('assist_today_title', sanitize_text_field($assist_today_title));

                $your_basket_title = (($_POST["your_basket_title"]));
                update_option('your_basket_title', sanitize_text_field($your_basket_title));

                $recommended_products_title = (($_POST["recommended_products_title"]));
                update_option('recommended_products_title', sanitize_text_field($recommended_products_title));

                $user_purchased_a_title = (($_POST["user_purchased_a_title"]));
                update_option('user_purchased_a_title', sanitize_text_field($user_purchased_a_title));

                $user_from_title = (($_POST["user_from_title"]));
                update_option('user_from_title', sanitize_text_field($user_from_title));


                if (isset($_POST["message_six"])) {
                    $button_text = stripslashes(($_POST["message_six"]));
                    update_option('message_six', $button_text);
                }
                if (isset($_POST["message_seven"])) {
                    $button_text = stripslashes(($_POST["message_seven"]));
                    update_option('message_seven', $button_text);
                }
                if (isset($_POST["message_eight"])) {
                    $button_text = stripslashes(($_POST["message_eight"]));
                    update_option('message_eight', $button_text);
                }


                $jarvis_form_animation = $_POST['jarvis_form_animation'] ? $_POST['jarvis_form_animation'] : '';
                update_option('jarvis_form_animation', sanitize_text_field($jarvis_form_animation));

                if (isset($_POST["cart_products"])) {
                    update_option('cart_products', sanitize_text_field($_POST['cart_products']));
                }else{
                    update_option('cart_products', '');

                }

                if (isset($_POST["jarvis_search"])) {
                    //$jarvis_search = $_POST['jarvis_search'] ? $_POST['jarvis_search'] : '';
                    update_option('jarvis_search', sanitize_text_field($_POST['jarvis_search']));
                }else{
                    update_option('jarvis_search', '');

                }

                if (isset($_POST["loop_notification"])) {
                    update_option('loop_notification', sanitize_text_field($_POST['loop_notification']));
                }else{
                    update_option('loop_notification', '');

                }


                if (isset($_POST["disable_notification"])) {
                    update_option('disable_notification', sanitize_text_field($_POST['disable_notification']));
                }else{
                    update_option('disable_notification', '');
                }


                $jarvis_icon = $_POST['jarvis_icon'] ? $_POST['jarvis_icon'] : 'icon-1.png';
                update_option('jarvis_icon', sanitize_text_field($jarvis_icon));

                $jarvis_search_popup = $_POST['jarvis_search_popup'] ? $_POST['jarvis_search_popup'] : '2';
                update_option('jarvis_search_popup', sanitize_text_field($jarvis_search_popup));


                $jarvis_theme = $_POST['jarvis_theme'] ? $_POST['jarvis_theme'] : 'theme-one.jpg';
                update_option('jarvis_theme', sanitize_text_field($jarvis_theme));

                if (isset($_POST["last_purchased_product"])) {
                    update_option('last_purchased_product', sanitize_text_field($_POST['last_purchased_product']));
                }else{
                    update_option('last_purchased_product', '');
                }


                //Support Quickball
                if (isset($_POST["support_quickball"])) {
                    update_option('support_quickball', esc_html($_POST['support_quickball']));
                }else{
                    
                    update_option('support_quickball', '');
                }

                if (isset($_POST["support_quickball_email"])) {
                    update_option('support_quickball_email', sanitize_text_field($_POST['support_quickball_email']));
                }else{
                    update_option('support_quickball_email', '');
                }
                //Custom Quickball


                if (isset($_POST["custom_quickball_link"])) {
                    update_option('custom_quickball_link', sanitize_text_field($_POST['custom_quickball_link']));
                }else{
                    update_option('custom_quickball_link', '');
                }


                if (isset($_POST["global_notification_delay_time"])) {
                    update_option('global_notification_delay_time', sanitize_text_field($_POST['global_notification_delay_time']));
                }else{
                    update_option('global_notification_delay_time', '');
                }

                if (isset($_POST["global_fake_sale_delay_time"])) {
                    update_option('global_fake_sale_delay_time', sanitize_text_field($_POST['global_fake_sale_delay_time']));
                }else{
                    update_option('global_fake_sale_delay_time', '');                
                }

                if (isset($_POST["global_widget_font_size"])) {
                    update_option('global_widget_font_size', sanitize_text_field($_POST['global_widget_font_size']));
                }else{
                    update_option('global_widget_font_size', '');                
                }

                if (isset($_POST["qcld_jarvis_front_tags"])) {
                    $grid_data = htmlentities(stripslashes($_POST['qcld_jarvis_front_tags']));
                }else{
                   $grid_data=''; 
                }


                if (isset($_POST["fake-product-one"])) {
                    update_option('fake-product-one', $_POST["fake-product-one"]);
                }else{
                    update_option('fake-product-one', '');
                }

                if (isset($_POST["fake-product-two"])) {
                    update_option('fake-product-two', $_POST["fake-product-two"]);
                }else{
                    update_option('fake-product-two', '');                
                }

                if (isset($_POST["fake-product-three"])) {
                    update_option('fake-product-three', $_POST["fake-product-three"]);
                }else{
                    update_option('fake-product-three','');

                }
                //Ajax search message setting
                $p_scs_msg = $_POST["p_scs_msg"];
                update_option('p_scs_msg', sanitize_text_field($p_scs_msg));
                $p_scs_msg = $_POST["p_fail_msg"];
                update_option('p_fail_msg', sanitize_text_field($p_scs_msg));


                //custom quickball icon

                if (isset($_FILES['custom_quickball_icon']['tmp_name']) && $_FILES['custom_quickball_icon']['tmp_name'] != "") {

                    $quickball_pic = 'custom_quickball_icon.png';
                    $quickball_img_path = QC_JARVIS_IMG_ABSOLUTE_PATH . '/quickball-icon/' . $quickball_pic;

                    $quickball_pic_loc = $_FILES['custom_quickball_icon']['tmp_name'];


                    if (move_uploaded_file($quickball_pic_loc, $quickball_img_path)) {
                        update_option('custom_quickball_icon', $quickball_pic);
                        ?>
                        <script> alert('successfully uploaded');</script><?php
                    } else {
                        ?>
                        <script> alert('error while uploading file');</script><?php
                    }


                }


                //Custom css to over write style.
                if (isset($_POST["custom_global_css"])) {
                    $custom_global_css = $_POST["custom_global_css"];
                    update_option('custom_global_css', $custom_global_css);
                }
                //Last sold products Language settings
                if (isset($_POST["last_sold_product_title"])) {
                    $last_sold_product_title = sanitize_text_field(($_POST["last_sold_product_title"]));
                    update_option('last_sold_product_title', $last_sold_product_title);
                }
                if (isset($_POST["no_last_sold_product"])) {
                    $no_last_sold_product = sanitize_text_field(($_POST["no_last_sold_product"]));
                    update_option('no_last_sold_product', $no_last_sold_product);
                }
                if (isset($_POST["last_sold_from"])) {
                    $last_sold_from = sanitize_text_field(($_POST["last_sold_from"]));
                    update_option('last_sold_from', $last_sold_from);
                }
                if (isset($_POST["last_sold_guest_from"])) {
                    $last_sold_guest_from = sanitize_text_field(($_POST["last_sold_guest_from"]));
                    update_option('last_sold_guest_from', $last_sold_guest_from);
                }
                if (isset($_POST["last_sold_just_purchased"])) {
                    $last_sold_just_purchased = sanitize_text_field(($_POST["last_sold_just_purchased"]));
                    update_option('last_sold_just_purchased', $last_sold_just_purchased);
                }
                if (isset($_POST["last_sold_purchased_a"])) {
                    $last_sold_purchased_a = sanitize_text_field(($_POST["last_sold_purchased_a"]));
                    update_option('last_sold_purchased_a', $last_sold_purchased_a);
                }
                if (isset($_POST["last_sold_time"])) {
                    $last_sold_time = sanitize_text_field(($_POST["last_sold_time"]));
                    update_option('last_sold_time', $last_sold_time);
                }
                //Cart language settings
                if (isset($_POST["cart_no_product_found"])) {
                    $cart_no_product_found = sanitize_text_field(($_POST["cart_no_product_found"]));
                    update_option('cart_no_product_found', $cart_no_product_found);
                }
                if (isset($_POST["cart_total_price"])) {
                    $cart_total_price = sanitize_text_field(($_POST["cart_total_price"]));
                    update_option('cart_total_price', $cart_total_price);
                }
                if (isset($_POST["cart_cart_link"])) {
                    $cart_cart_link = sanitize_text_field(($_POST["cart_cart_link"]));
                    update_option('cart_cart_link', $cart_cart_link);
                }
                if (isset($_POST["cart_checkout_link"])) {
                    $cart_checkout_link = sanitize_text_field(($_POST["cart_checkout_link"]));
                    update_option('cart_checkout_link', $cart_checkout_link);
                }
                //recent view product language settings.
                if (isset($_POST["recently_viewed_add_to_cart"])) {
                    $recently_viewed_add_to_cart = sanitize_text_field(($_POST["recently_viewed_add_to_cart"]));
                    update_option('recently_viewed_add_to_cart', $recently_viewed_add_to_cart);
                }
                if (isset($_POST["recently_viewed_details"])) {
                    $recently_viewed_details = sanitize_text_field(($_POST["recently_viewed_details"]));
                    update_option('recently_viewed_details', $recently_viewed_details);
                }
                if (isset($_POST["recently_viewed_no_product_founnd"])) {
                    $recently_viewed_no_product_founnd = sanitize_text_field(($_POST["recently_viewed_no_product_founnd"]));
                    update_option('recently_viewed_no_product_founnd', $recently_viewed_no_product_founnd);
                }
                //Quickball setting

                if (isset($_POST["jarvis_support_form_title"])) {
                    $jarvis_support_form_title = sanitize_text_field(($_POST["jarvis_support_form_title"]));
                    update_option('jarvis_support_form_title', $jarvis_support_form_title);
                }
            }
        }
    }

    function jarvis_search_query($query)
    {
        global $woocommerce, $wp_query, $wpdb;

        if (!is_admin() && $query->is_main_query()) {

            $woocommerce_current_page_id = (version_compare($woocommerce->version, '2.1', '<')) ? woocommerce_get_page_id('shop') : wc_get_page_id('shop');

            if (is_shop() || ($query->is_page() && 'page' == get_option('show_on_front') && $query->get('page_id') == $woocommerce_current_page_id)) {

                $product_categories = (isset($_GET['sa_product_cat'])) ? $_GET['sa_product_cat'] : null;
                $product_tags = (isset($_GET['sa_product_tag'])) ? $_GET['sa_product_tag'] : null;

                if (isset($product_categories) || ($product_tags)) {
                    add_filter("woocommerce_is_filtered", array($this, 'woocommerce_is_filtered'));
                }

                $tax_query = false;

                // Product Attributes
                $attribute_taxonomies = wc_get_attribute_taxonomies();
                $selected_attributes = false;

                if ($attribute_taxonomies) {

                    foreach ($attribute_taxonomies as $tax) {

                        $attribute = sanitize_title($tax->attribute_name);
                        $taxonomy = wc_attribute_taxonomy_name($attribute);

                        // create an array of product attribute taxonomies
                        $_attributes_array[] = $taxonomy;

                        $name = 'sa_filter_' . $attribute;

                        if (!empty($_GET[$name]) && taxonomy_exists($taxonomy)) {
                            add_filter("woocommerce_is_filtered", array($this, 'woocommerce_is_filtered'));
                            $selected_attributes[$taxonomy]['terms'] = $_GET[$name];

                        }
                    }

                    if ($selected_attributes) {

                        foreach ($selected_attributes as $key => $value) {

                            $tax_query[] = array(
                                'taxonomy' => $key,
                                'field' => 'id',
                                'terms' => $value["terms"],
                                'operator' => 'IN'
                            );

                        }

                    }
                }

                // Product Categories
                if ((isset($product_categories)) && ($product_categories != "")) {

                    $tax_query[] = array(
                        'taxonomy' => 'product_cat',
                        'field' => 'id',
                        'terms' => $product_categories,
                        'operator' => 'IN'
                    );

                }

                // Product Tags
                if ((isset($product_tags)) && ($product_tags != "")) {

                    $tax_query[] = array(
                        'taxonomy' => 'product_tag',
                        'field' => 'id',
                        'terms' => $product_tags,
                        'operator' => 'IN'
                    );

                }

                if ($tax_query) {
                    add_filter("woocommerce_page_title", array($this, "jarvis_title"));
                    $tax_query['relation'] = 'AND';
                    $query->set('tax_query', $tax_query);
                }

            }
        }
        return $query;
        ///
    }

    function woocommerce_is_filtered()
    {

        return true;
    }

    function jarvis_title($title)
    {

        return __("Search Results:", "jarvis");
    }

    /**
     * Price Filter post filter
     */
    function jarvis_price_filter($filtered_posts)
    {
        global $wpdb;

        if (isset($_GET['sa_max_price']) && isset($_GET['sa_min_price'])) {

            add_filter("woocommerce_is_filtered", array($this, 'woocommerce_is_filtered'));

            $matched_products = array();
            $min = floatval($_GET['sa_min_price']);
            $max = floatval($_GET['sa_max_price']);

            $matched_products_query = $wpdb->get_results($wpdb->prepare("
	        	SELECT DISTINCT ID, post_parent, post_type FROM $wpdb->posts
				INNER JOIN $wpdb->postmeta ON ID = post_id
				WHERE post_type IN ( 'product', 'product_variation' ) AND post_status = 'publish' AND meta_key = %s AND meta_value BETWEEN %d AND %d
			", '_price', $min, $max), OBJECT_K);

            if ($matched_products_query) {
                foreach ($matched_products_query as $product) {
                    if ($product->post_type == 'product')
                        $matched_products[] = $product->ID;
                    if ($product->post_parent > 0 && !in_array($product->post_parent, $matched_products))
                        $matched_products[] = $product->post_parent;
                }
            }

            // Filter the id's
            if (sizeof($filtered_posts) == 0) {
                $filtered_posts = $matched_products;
                $filtered_posts[] = 0;
            } else {
                $filtered_posts = array_intersect($filtered_posts, $matched_products);
                $filtered_posts[] = 0;
            }

        }
        return (array)$filtered_posts;
    }

    /**
     * Display Notifications on specific criteria.
     *
     * @since    2.14
     */
    public static function woocommerce_inactive_notice()
    {
        if (current_user_can('activate_plugins')) :
            if (!class_exists('WooCommerce')) :
                deactivate_plugins(plugin_basename(__FILE__));
                ?>
                <div id="message" class="error">
                    <p>
                        <?php
                        printf(
                            __('%sJARVIS for WooCommerce REQUIRES WooCommerce%s %sWooCommerce%s must be active for JARVIS to work. Please install & activate WooCommerce.', 'jarvis'),
                            '<strong>',
                            '</strong><br>',
                            '<a href="http://wordpress.org/extend/plugins/woocommerce/" target="_blank" >',
                            '</a>'
                        );
                        ?>
                    </p>
                </div>
                <?php
            elseif (version_compare(get_option('woocommerce_db_version'), QC_JARVIS_REQUIRED_WOOCOMMERCE_VERSION, '<')) :
                ?>
                <div id="message" class="error">
                    <!--<p style="float: right; color: #9A9A9A; font-size: 13px; font-style: italic;">For more information <a href="http://cxthemes.com/plugins/update-notice.html" target="_blank" style="color: inheret;">click here</a></p>-->
                    <p>
                        <?php
                        printf(
                            __('%sJARVIS for WooCommerce is inactive%s This version of JARVIS requires WooCommerce %s or newer. For more information about our WooCommerce version support %sclick here%s.', 'jarvis'),
                            '<strong>',
                            '</strong><br>',
                            QC_JARVIS_REQUIRED_WOOCOMMERCE_VERSION
                        );
                        ?>
                    </p>
                    <div style="clear:both;"></div>
                </div>
                <?php
            endif;
        endif;
    }

}

/**
 * Instantiate plugin.
 *
 */

if (!function_exists('init_jarvis')) {
    function init_jarvis()
    {

        global $wc_jarvis;

        $wc_jarvis = WC_Jarvis::get_instance();
    }
}
add_action('plugins_loaded', 'init_jarvis');


register_activation_hook(__FILE__, 'jarvis_insert_demo_content');
function jarvis_insert_demo_content()
{

    $demo_data = array(
        0 => array(
            'text' => 'Find Products In',
            'filter' => 'product_cat',
            'priceone' => '',
            'pricetwo' => '',
            'label' => 'Category'
        ),
        1 => array(
            'text' => 'Between Price',
            'filter' => 'price',
            'priceone' => '100',
            'pricetwo' => '500',
            'label' => ''
        )
    );
    update_option('jarvis_icon', 'icon-0.png');

    if (get_option('jarvis-terms-fields') == '') {
        update_option('jarvis-terms-fields', serialize($demo_data));
    }
    if (get_option('jarvis_theme') == '') {
        update_option('jarvis_theme', 'theme-one.jpg');
    }

    update_option('loop_notification', 1);
    update_option('jarvis_search', 'jarvis_search');
    update_option('cart_products', 'cart_products');
    update_option('recommended_products', '');
    update_option('recent_products', 'recent_products');
    update_option('jarvis_form_animation', 'bounce');

    // Default search result page when plugin installed/activated/updated
    update_option('jarvis_search_popup', 1);

    update_option('global_notification_delay_time', 5);
    update_option('global_fake_sale_delay_time', 5);
    update_option('jarvis_mode', 'quickball');
    update_option('global_widget_font_size', '20');
    update_option('disable_jarvis', 1);


    update_option('fake_sale_notification', 'fake_sale_notification');
    update_option('fake_sale_notification_sound', 'fake_sale_notification_sound');
    update_option('sell_notification_off_mobile', 'sell_notification_off_mobile');


    update_option('position_x', 50);
    update_option('position_y', 50);
    update_option('message_one', "Hi, I am JARVIS. What can I help you with today?");
    update_option('notification_delay_one', 2);
    //Ajax search message settings
    if (get_option('p_scs_msg') != '') {
        update_option('p_scs_msg', 'Great! We have these products.');
    }
    if (get_option('p_fail_msg') != '') {
        update_option('p_fail_msg', 'Oops! Nothing matches your exact criteria. How about selecting some different options?');
    }
    update_option('user_from_title', 'From');
    update_option('user_purchased_a_title', 'Purchased a');
    //Last solde products language settings
    update_option('last_sold_product_title', 'Recently Sold Products');
    update_option('no_last_sold_product', 'No recently sold products found.');
    update_option('last_sold_from', 'from');
    update_option('last_sold_guest_from', 'Guest from');
    update_option('last_sold_just_purchased', 'just purchased');
    update_option('last_sold_purchased_a', 'Purchased a');
    update_option('last_sold_time', 'About 20 minutes  ago');
    //Cart language settenings
    update_option('cart_no_product_found', 'You do not have any products in the cart');
    update_option('cart_total_price', 'Total Price');
    update_option('cart_cart_link', 'Cart');
    update_option('cart_checkout_link', 'Checkout');
    // Recent view product language settings
    update_option('recently_viewed_add_to_cart', 'Add to cart');
    update_option('recently_viewed_details', 'View Detail');
    update_option('recently_viewed_no_product_founnd', 'You have not viewed any products yet !');
    update_option('jarvis_support_form_title', 'Questions or Comments?
Contact Us');

    //Registrating uninstalling hook

}



//
add_action('wp_ajax_jarvis_delete_all_options_for_uninstall', 'jarvis_delete_all_options_for_uninstall');
add_action('wp_ajax_nopriv_jarvis_delete_all_options_for_uninstall', 'jarvis_delete_all_options_for_uninstall');
//Jarvis all option will be delete during uninstlling.
function jarvis_delete_all_options_for_uninstall()
{
    delete_option('jarvis_icon');
    delete_option('jarvis-terms-fields');
    delete_option('jarvis_theme');
    //delete_option('cart_products');
    delete_option('disable_jarvis');


    delete_option('position_x');
    delete_option('position_y');
    //delete_option('message_one');
    delete_option('p_scs_msg');
    delete_option('p_fail_msg');
    delete_option('user_from_title');
    delete_option('user_purchased_a_title');
    delete_option('last_sold_product_title');
    delete_option('no_last_sold_product');
    delete_option('last_sold_from');
    delete_option('last_sold_guest_from');
    delete_option('last_sold_just_purchased');
    delete_option('last_sold_purchased_a');
    delete_option('last_sold_time');
    delete_option('cart_no_product_found');
    delete_option('cart_total_price');
    delete_option('cart_cart_link');
    delete_option('cart_checkout_link');
    //delete_option('recently_viewed_add_to_cart');
    //delete_option('recently_viewed_details');
    //delete_option('recently_viewed_no_product_founnd');
    //delete_option('jarvis-search-button-text');
    delete_option('artificial_orders_val');
    delete_option('notification_delay_one');
    delete_option('notification_delay_two');
    delete_option('notification_delay_thre');
    delete_option('notification_delay_four');
    delete_option('notification_delay_five');
    delete_option('notification_delay_six');
    delete_option('notification_delay_seven');
    delete_option('notification_delay_eight');
    update_option('jarvis_mode', 'quickball');
    delete_option('disable_cart_item');
    delete_option('disable_jarvis_icon_animation');
//    delete_option('customer_name_one');
//    delete_option('customer_address_one');
//    delete_option('customer_name_two');
//    delete_option('customer_address_two');
//    delete_option('customer_name_three');
//    delete_option('customer_address_three');
    delete_option('recently_viewed_products_title');
    delete_option('assist_today_title');
    delete_option('your_basket_title');
    delete_option('recommended_products_title');
    delete_option('message_six');
    delete_option('message_seven');
    delete_option('message_eight');
    delete_option('jarvis_form_animation');
    delete_option('cart_products');

    delete_option('loop_notification');
    delete_option('disable_notification');
    delete_option('recommended_products');
    //delete_option('jarvis_search_popup');
    delete_option('last_purchased_product');
    //delete_option('recent_products');
    delete_option('custom_quickball');
    delete_option('custom_quickball_link');
    delete_option('custom_quickball_icon');
    delete_option('global_notification_delay_time');
    delete_option('global_fake_sale_delay_time');
    delete_option('global_widget_font_size');
    delete_option('jarvis-recommended-products');
    delete_option('fake-product-one');
    delete_option('fake-product-two');
    delete_option('fake-product-three');
    delete_option('custom_global_css');
    delete_option('jarvis_support_form_title');


    $demo_data = array(
        0 => array(
            'text' => 'Find Products In',
            'filter' => 'product_cat',
            'priceone' => '',
            'pricetwo' => '',
            'label' => 'Category'
        ),
        1 => array(
            'text' => 'Between Price',
            'filter' => 'price',
            'priceone' => '100',
            'pricetwo' => '500',
            'label' => ''
        )
    );
    update_option('jarvis_icon', 'icon-0.png');

    if (get_option('jarvis-terms-fields') == '') {
        update_option('jarvis-terms-fields', serialize($demo_data));
    }
    if (get_option('jarvis_theme') == '') {
        update_option('jarvis_theme', 'theme-one.jpg');
    }

    update_option('loop_notification', 1);
    update_option('jarvis_search', 'jarvis_search');

    update_option('cart_products', 'cart_products');
    update_option('recommended_products', '');
    update_option('recent_products', 'recent_products');
    update_option('jarvis_form_animation', 'bounce');

    // Default search result page when plugin installed/activated/updated
    update_option('jarvis_search_popup', 1);

    update_option('global_notification_delay_time', 5);
    update_option('global_fake_sale_delay_time', 5);
    update_option('jarvis_mode', 'quickball');
    update_option('global_widget_font_size', '20');
    update_option('disable_jarvis', 1);


    update_option('fake_sale_notification', 'fake_sale_notification');
    update_option('fake_sale_notification_sound', 'fake_sale_notification_sound');
    update_option('sell_notification_off_mobile', 'sell_notification_off_mobile');


    update_option('position_x', 50);
    update_option('position_y', 50);
    update_option('message_one', "Hi, I am JARVIS. What can I help you with today?");
    update_option('notification_delay_one', 2);
    //Ajax search message settings
    if (get_option('p_scs_msg') != '') {
        update_option('p_scs_msg', 'Great! We have these products.');
    }
    if (get_option('p_fail_msg') != '') {
        update_option('p_fail_msg', 'Oops! Nothing matches your exact criteria. How about selecting some different options?');
    }
    update_option('user_from_title', 'From');
    update_option('user_purchased_a_title', 'Purchased a');
    //Last solde products language settings
    update_option('last_sold_product_title', 'Recently Sold Products');
    update_option('no_last_sold_product', 'No recently sold products found.');
    update_option('last_sold_from', 'from');
    update_option('last_sold_guest_from', 'Guest from');
    update_option('last_sold_just_purchased', 'just purchased');
    update_option('last_sold_purchased_a', 'Purchased a');
    update_option('last_sold_time', 'About 20 minutes  ago');
    //Cart language settenings
    update_option('cart_no_product_found', 'You do not have any products in the cart');
    update_option('cart_total_price', 'Total Price');
    update_option('cart_cart_link', 'Cart');
    update_option('cart_checkout_link', 'Checkout');
    // Recent view product language settings
    update_option('recently_viewed_add_to_cart', 'Add to cart');
    update_option('recently_viewed_details', 'View Detail');
    update_option('recently_viewed_no_product_founnd', 'You have not viewed any products yet !');
    update_option('jarvis_support_form_title', 'Questions or Comments? Contact Us');


    $html = 'Reset all options to default successfully.';
    wp_send_json($html);
    wp_die();
}

/**
 *
 * deactive Plugin Feedback.
 *
 */
$wpbot_feedback = new Wp_jarvis_assistant_Usage_Feedback(
            __FILE__,
            'quantumcloud@gmail.com',
            false,
            true

        );